@@ -17,6 +17,6 @@ class PluginRequest(JsonSerializable):
     def from_json(cls, json_dict: Dict[str, Any]) -> Self:
         return {
             'url' in json_dict: lambda: PluginRequest(**json_dict),
-            'resource_id' in json_dict: lambda: PluginContext(**json_dict)
+            'localized_resources' in json_dict: lambda: PluginContext(**json_dict)
         }.get(True, lambda: json_dict)()
 
